/*
 * ********************************************************************************************************************
 *
 *                      :*$@@%$*:                         ;:                ;;    ;;
 *                    :@@%!  :!@@%:                       %!             ;%%@@%$ =@@@@@@@%;     @%@@@%%%%@@@@@
 *                   :@%;       :$=                       %%$$$%$$         ;$$  ;$@=   !@$
 *                   =@!                                  %!              @ $=;%   !@@@%:      !$$$$$$$$$$$$$$=
 *                   =@*                                  %!              @ $= % %@=   =%@!      %=
 *              *$%%! @@=        ;=$%%%$*:                %!              @ $= % =%%%%%%@$      *%:         =%
 *            %@@!:    !@@@%=$@@@@%!  :*@@$:              %!              @ $= % $*     ;@      @*          :%*
 *          ;@@!          ;!!!;:         ;@%:      =======@%========*     @ $$ % $%*****$@     :@$=*********=@$
 *          $@*   ;@@@%=!:                *@*
 *          =@$    ;;;!=%@@@@=!           =@!
 *           %@$:      =@%: :*@@@*       %@=                    Copyright (c) 2016-2019.  北京上格云技术有限公司
 *            ;%@@$=$@@%*       *@@@$=%@@%;
 *               ::;::             ::;::                                              All rights reserved.
 *
 * ********************************************************************************************************************
 */

import { SGraphyCommand } from "@saga-web/graphy/lib";
import { SPoint } from "@saga-web/draw/lib";
import { SGraphItem, SGraphCommand } from "@saga-web/graph";

/**
 * 多边形、折线等相关顶点的位置更新命令
 *
 * @author  韩耀龙
 */

export class SPointListUpdate extends SGraphCommand {
    /**  指向item对象 */
    item: SGraphItem;
    /**  原位置 */
    old: SPoint;
    /**  当前位置 */
    pos: SPoint;
    /** 索引 */
    index: number;
    /** 顶点数组 */
    pointList: SPoint[];

    /**
     * 构造函数
     * @param   item        指向item对象
     * @param   pointList   顶点数组
     * @param   old         原位置
     * @param   pos         当前位置
     * @param   index       索引
     */
    constructor(item: SGraphItem, pointList: SPoint[], old: SPoint, pos: SPoint, index: number) {
        super(null);
        this.item = item;
        this.old = old;
        this.pos = pos;
        this.index = index;
        this.pointList = pointList;
    }
    // mergeWith(command: SUndoCommand): boolean {
    //     return false;
    // }

    /**
     * 执行重做操作执行
     */
    redo(): void {
        this.pointList[this.index].x = this.pos.x;
        this.pointList[this.index].y = this.pos.y;
        this.item.update();
    }

    /**
     * 执行取消操作执行
     */
    undo(): void {
        this.pointList[this.index].x = this.old.x;
        this.pointList[this.index].y = this.old.y;
        this.item.update();
    }
}
